'use strict';

var _tildify = require('tildify');

var _tildify2 = _interopRequireDefault(_tildify);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _subdir = require('subdir');

var _subdir2 = _interopRequireDefault(_subdir);

var _liftoff = require('liftoff');

var _liftoff2 = _interopRequireDefault(_liftoff);

var _logger = require('./logger');

var _logger2 = _interopRequireDefault(_logger);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _helpers = require('./helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const options = require('yargs').version(_package2.default.version).usage('\nUsage: spin [options] <tasks ...>').example('spin clean build test', 'Run commands in sequence').example('spin -p clean+build lint', 'Run clean & build in sequence, and lint in parallel').option('spinfile', {
  describe: 'Alternative spinfile to use',
  type: 'string'
}).option('tasks', {
  boolean: true,
  describe: 'Display available tasks'
}).option('parallel', {
  alias: 'p',
  boolean: true,
  describe: 'Run in parallel mode'
}).option('babel', {
  default: true,
  boolean: true,
  describe: 'Enable babel'
}).option('babelrc', {
  type: 'string',
  nargs: 1,
  describe: 'Babel resource file'
}).option('silent', {
  boolean: true,
  describe: 'Disable all logging'
}).option('verboe', {
  alias: 'debug',
  boolean: true,
  describe: 'Enable all logging'
}).option('info', {
  boolean: true,
  describe: 'Display contextual information'
}).option('verbosity', {
  choices: ['all', 'error', 'warn', 'notice', 'info', 'none'],
  default: 'notice'
}).help('h').alias('h', 'help').epilog('For more information visite https://spinr.github.io').argv;

if (options.silent) {
  _logger2.default.verbosity = 'none';
} else if (options.verbose || options.debug || options.info) {
  _logger2.default.verbosity = 'all';
} else {
  _logger2.default.verbosity = options.verbosity;
}

if (options.babelrc) {
  // Register custom babel configuration
  const babelrc = (0, _helpers.loadBabelConfigFrom)(options.babelrc);
  require('babel-register')(Object.assign(babelrc, {
    ignore: name => !(0, _subdir2.default)(process.cwd(), name) || /node_modules/.test(name)
  }));
} else if (options.babel === true) {
  // Register spinr babel configuration
  require('babel-register')(Object.assign(_package2.default.babel, {
    ignore: name => !(0, _subdir2.default)(process.cwd(), name) || /node_modules/.test(name)
  }));
}

['uncaughtException', 'unhandledRejection'].forEach(event => {
  process.on(event, error => {
    _logger2.default.error(error);
    if (error.stack) _logger2.default.error(error.stack, { aside: false });
    process.exit(1);
  });
});

const cli = new _liftoff2.default({
  name: 'spinr',
  configName: 'spinfile'
});

// Lets spin!
cli.launch({
  cwd: options.cwd,
  configPath: options.spinfile,
  verbose: options.verbose
}, (() => {
  var _ref = _asyncToGenerator(function* (env) {
    if (options.debug || options.info) {
      _logger2.default.info('=== Spinr context ===');
      _logger2.default.log('CLI OPTIONS:', process.argv);
      _logger2.default.log('CWD:', env.cwd);
      _logger2.default.log('LOCAL MODULES PRELOADED:', env.require);
      _logger2.default.log('SEARCHING FOR:', env.configNameRegex);
      _logger2.default.log('FOUND CONFIG AT:', env.configPath);
      _logger2.default.log('CONFIG BASE DIR:', env.configBase);
      _logger2.default.log('YOUR LOCAL MODULE IS LOCATED:', env.modulePath);
      _logger2.default.log('LOCAL PACKAGE.JSON:', env.modulePackage);
      _logger2.default.log('CLI PACKAGE.JSON', _package2.default);
    }

    if (options.info) process.exit(0);

    if (options.version && options.tasks.length === 0) {
      _logger2.default.log('CLI version', _package2.default.version);
      if (env.modulePackage && typeof env.modulePackage.version !== 'undefined') {
        _logger2.default.log('Local version', env.modulePackage.version);
      }
      process.exit(0);
    }

    if (!env.configPath) {
      _logger2.default.error(`no ${ cli.configName } found.`);
      process.exit(1);
    } else {
      _logger2.default.log('Using spinfile', _chalk2.default.magenta((0, _tildify2.default)(env.configPath)));
    }

    const spinfile = require(env.configPath);

    if (options.tasks) {
      _logger2.default.log(`Tasks for ${ _chalk2.default.magenta(env.configPath) }`);
      Object.keys(spinfile).forEach(function (task) {
        return _logger2.default.log('-', task);
      });
      process.exit(0);
    }

    if (!env.modulePath) {
      _logger2.default.error(`Local spinr not found in: ${ (0, _tildify2.default)(env.cwd) }`);
      process.exit(1);
    }

    const spin = require(env.modulePath);
    yield spin.runner(spinfile, options);
  });

  return function (_x) {
    return _ref.apply(this, arguments);
  };
})());
//# sourceMappingURL=cli.js.map