'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Timer = undefined;
exports.loadBabelConfigFrom = loadBabelConfigFrom;
exports.isFunction = isFunction;
exports.isStream = isStream;
exports.timestamp = timestamp;
exports.promisify = promisify;

var _path = require('path');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function loadBabelConfigFrom(path, relative = process.cwd()) {
  const absPath = (0, _path.isAbsolute)(path) ? path : (0, _path.join)(relative, path);
  const resource = JSON.parse(_fs2.default.readFileSync(absPath, 'utf8'));

  return resource.babel ? resource.babel : resource;
}

function isFunction(thing) {
  return thing !== undefined && thing !== null && typeof thing === 'function';
}

function isStream(thing) {
  return thing !== undefined && thing !== null && typeof thing === 'object' && typeof thing.pipe === 'function';
}

function timestamp(options = { date: new Date() }) {
  return options.date.toTimeString().replace(/.*(\d{2}:\d{2}:\d{2}).*/, '$1');
}

function promisify(callback, options = {}) {
  return (...args) => new Promise((resolve, reject) => {
    try {
      const ctx = options.context || this;
      callback.apply(ctx, [...args, (err, res) => {
        if (err) {
          reject(err);
        }

        resolve(res);
      }]);
    } catch (e) {
      reject(e);
    }
  });
}

class Timer {
  constructor() {
    this.start();
    this.stop();
  }

  start() {
    this.startTime = Date.now();
    return this;
  }

  stop() {
    this.stopTime = Date.now();
    return this;
  }

  getTotalTime() {
    return this.stopTime - this.startTime;
  }

  getTotalTimeInSec() {
    return (this.getTotalTime() / 1000).toFixed(2);
  }
}

exports.Timer = Timer;
exports.default = {
  loadBabelConfigFrom,
  isFunction,
  isStream,
  timestamp,
  promisify,
  Timer
};
//# sourceMappingURL=helpers.js.map