'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _helpers = require('./helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const INSTANCE = Symbol.for('spinr@global');

const LEVELS = Object.freeze({
  none: Infinity,
  error: 5,
  notice: 4,
  warn: 3,
  info: 2,
  all: 1
});

const FORMATTERS = [
/* eslint-disable no-console */
{ name: 'log', handler: console.log },
/* eslint-enable no-console */
{ name: 'info', output: process.stdout, format: _chalk2.default.blue }, { name: 'warn', output: process.stderr, format: _chalk2.default.cyan }, { name: 'error', output: process.stderr, format: _chalk2.default.red }, {
  name: 'time',
  output: process.stdout,
  format: _chalk2.default.bold,
  aside: option => `[${ (0, _helpers.timestamp)(option) }]`,
  level: LEVELS.notice
}];

function asideFrom(formatter, options) {
  if (options.aside !== undefined) {
    return options.aside;
  } else if ((0, _helpers.isFunction)(formatter.aside)) {
    return formatter.aside(options);
  } else if (formatter.aside === false) {
    return false;
  }

  return formatter.name;
}

function verbosityFrom(formatter) {
  if (formatter.level) {
    return formatter.level;
  }

  return LEVELS[formatter.name] || LEVELS.notice;
}

function write(message, formatter, verbosity, options = {}) {
  const aside = asideFrom(formatter, options);
  const level = verbosityFrom(formatter);

  if (level >= verbosity) {
    formatter.output.write(`${ aside ? `${ formatter.format(aside) } ` : '' }${ message }\n`);
  }
}

class Logger {
  constructor() {
    this.level = LEVELS.notice;
    FORMATTERS.forEach(formatter => {
      this[formatter.name] = formatter.handler || ((message, options) => {
        write(message, formatter, this.verbosity, options);
      });
    });
  }

  set verbosity(name) {
    this.level = LEVELS[name] || LEVELS.notice;
  }

  get verbosity() {
    return this.level;
  }
}

// Export a singleton

exports.default = (() => {
  let logger = global[INSTANCE];

  if (!logger) {
    logger = global[INSTANCE] = new Logger();
  }

  return logger;
})();
//# sourceMappingURL=logger.js.map